@@ -10,34 +10,34 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.18-194.11.AXS3.src.rpm ]
+if [ ! -r kernel-2.6.18-274.2.AXS3.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Asianux/Server/3.0/updates/src/kernel-2.6.18-194.11.AXS3.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Asianux/Server/3.0/updates/src/kernel-2.6.18-274.2.AXS3.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.18-194.11.AXS3.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.18-194.11.AXS3.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.18-274.2.AXS3.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.18-274.2.AXS3.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.2-20110726.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20111111.tar.gz ]
 then
-    wget -O ccs-patch-1.8.2-20110726.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110726.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20111111.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111111.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /usr/src/asianux/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
+cp -p /usr/src/asianux/SPECS/kernel.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec
-+++ kernel-2.6.spec
-@@ -66,7 +66,7 @@
- %define kversion 2.6.%{sublevel}
+--- kernel.spec
++++ kernel.spec
+@@ -68,7 +68,7 @@
+ %define kversion 2.6.%{sublevel}.%{stablerev}
  %define rpmversion 2.6.%{sublevel}
  # %dist is defined in Asianux VPBS
--%define release 194.11%{?dist}
-+%define release 194.11%{?dist}_tomoyo_1.8.2p2
+-%define release %{revision}.2%{dist}
++%define release %{revision}.2%{dist}_tomoyo_1.8.3p2
  %define signmodules 0
  %define xen_hv_cset 15502
  %define xen_abi_ver 3.1
-@@ -288,6 +288,9 @@
+@@ -277,6 +277,9 @@
  # to versions below the minimum
  #
  
@@ -47,7 +47,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -318,7 +321,7 @@
+@@ -307,7 +310,7 @@
  #
  %define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 4.2.21-1
  
@@ -56,19 +56,19 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -10699,6 +10702,10 @@
- 
- # END OF PATCH APPLICATIONS
+@@ -1043,6 +1046,10 @@
+ %patch200100 -p1
+ # end of Asianux patches
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.2-20110726.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20111111.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.18-asianux-3.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -10766,6 +10773,9 @@
- for i in `ls *86*.config *ia64*.config`
+@@ -1094,6 +1101,9 @@
+ for i in `ls *86*.config`
  do
    mv $i .config
 +  # TOMOYO Linux
@@ -78,7 +78,7 @@ patch << "EOF" || die "Can't patch spec file."
    make ARCH=$Arch nonint_oldconfig > /dev/null
    echo "# $Arch" > configs/$i
 EOF
-mv kernel-2.6.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
@@ -87,7 +87,7 @@ echo "rpmbuild -bb /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
 ARCH=`uname -m`
-echo "I'll start 'rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+echo "I'll start 'rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo --without source /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /tmp/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo --without source /tmp/ccs-kernel.spec
 exit 0
